@@ -9,9 +9,9 @@ use PMVersions::Util qw(version_from_pmversions);
 use Require::Hook::Source::DzilBuild;
 
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
-our $DATE = '2023-09-03'; # DATE
+our $DATE = '2024-01-09'; # DATE
 our $DIST = 'Dist-Zilla-Plugin-Sah-Schemas'; # DIST
-our $VERSION = '0.031'; # VERSION
+our $VERSION = '0.032'; # VERSION
 
 with (
     'Dist::Zilla::Role::CheckPackageDeclared',
@@ -306,6 +306,30 @@ sub register_prereqs {
                 $self->zilla->register_prereqs({phase=>'runtime'}, $crmod => version_from_pmversions($crmod) // 0);
             }
         }
+        # add prereqs to filter modules
+        for my $key ('prefilters', 'postfilters') {
+            my $filters = $nsch->[1]{$key};
+            next unless $filters && @$filters;
+            for my $filter (@$filters) {
+                my $filtername = ref $filter ? $filter->[0] : $filter;
+                my $filtermod = "Data::Sah::Filter::perl::$filtername";
+                next if $self->is_package_declared($filtermod);
+                $self->log(["Adding prereq to %s", $filtermod]);
+                $self->zilla->register_prereqs({phase=>'runtime'}, $filtermod => version_from_pmversions($filtermod) // 0);
+            }
+        }
+        # add prereqs to value rule modules
+        for my $key ('x.perl.default_value_rules') {
+            my $rules = $nsch->[1]{$key};
+            next unless $rules && @$rules;
+            for my $rule (@$rules) {
+                my $rulename = ref $rule ? $rule->[0] : $rule;
+                my $rulemod = "Data::Sah::Value::perl::$rulename";
+                next if $self->is_package_declared($rulemod);
+                $self->log(["Adding prereq to %s", $rulemod]);
+                $self->zilla->register_prereqs({phase=>'runtime'}, $rulemod => version_from_pmversions($rulemod) // 0);
+            }
+        }
     }
 }
 
@@ -325,7 +349,7 @@ Dist::Zilla::Plugin::Sah::Schemas - Plugin to use when building Sah-Schemas-* di
 
 =head1 VERSION
 
-This document describes version 0.031 of Dist::Zilla::Plugin::Sah::Schemas (from Perl distribution Dist-Zilla-Plugin-Sah-Schemas), released on 2023-09-03.
+This document describes version 0.032 of Dist::Zilla::Plugin::Sah::Schemas (from Perl distribution Dist-Zilla-Plugin-Sah-Schemas), released on 2024-01-09.
 
 =head1 SYNOPSIS
 
@@ -438,7 +462,7 @@ that are considered a bug and can be reported to me.
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2023, 2022, 2021, 2020, 2019, 2018, 2017, 2016 by perlancar <perlancar@cpan.org>.
+This software is copyright (c) 2024, 2023, 2022, 2021, 2020, 2019, 2018, 2017, 2016 by perlancar <perlancar@cpan.org>.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
